@@ -53,9 +53,6 @@ enum
 
 /* static guint gtk_champlain_embed_embed_signals[LAST_SIGNAL] = { 0, }; */
 
-#define GET_PRIVATE(obj) \
-  (G_TYPE_INSTANCE_GET_PRIVATE ((obj), GTK_CHAMPLAIN_TYPE_EMBED, GtkChamplainEmbedPrivate))
-
 struct _GtkChamplainEmbedPrivate
 {
   GtkWidget *clutter_embed;
@@ -98,7 +95,7 @@ static gboolean stage_key_press_cb (ClutterActor *actor,
     ClutterEvent *event,
     GtkChamplainEmbed *embed);
 
-G_DEFINE_TYPE (GtkChamplainEmbed, gtk_champlain_embed, GTK_TYPE_ALIGNMENT);
+G_DEFINE_TYPE_WITH_PRIVATE (GtkChamplainEmbed, gtk_champlain_embed, GTK_TYPE_ALIGNMENT)
 
 static void
 gtk_champlain_embed_get_property (GObject *object,
@@ -175,8 +172,6 @@ gtk_champlain_embed_finalize (GObject *object)
 static void
 gtk_champlain_embed_class_init (GtkChamplainEmbedClass *klass)
 {
-  g_type_class_add_private (klass, sizeof (GtkChamplainEmbedPrivate));
-
   GObjectClass *object_class = G_OBJECT_CLASS (klass);
   object_class->finalize = gtk_champlain_embed_finalize;
   object_class->dispose = gtk_champlain_embed_dispose;
@@ -222,8 +217,9 @@ set_view (GtkChamplainEmbed *embed,
 static void
 gtk_champlain_embed_init (GtkChamplainEmbed *embed)
 {
-  GtkChamplainEmbedPrivate *priv = GET_PRIVATE (embed);
+  GtkChamplainEmbedPrivate *priv = gtk_champlain_embed_get_instance_private (embed);
   ClutterActor *stage;
+  GdkDisplay *display;
 
   embed->priv = priv;
 
@@ -246,8 +242,9 @@ gtk_champlain_embed_init (GtkChamplainEmbed *embed)
       G_CALLBACK (mouse_button_cb),
       embed);
   /* Setup cursors */
-  priv->cursor_hand_open = gdk_cursor_new (GDK_HAND1);
-  priv->cursor_hand_closed = gdk_cursor_new (GDK_FLEUR);
+  display = gdk_display_get_default ();
+  priv->cursor_hand_open = gdk_cursor_new_for_display (display, GDK_HAND1);
+  priv->cursor_hand_closed = gdk_cursor_new_for_display (display, GDK_FLEUR);
 
   priv->view = NULL;
   set_view (embed, CHAMPLAIN_VIEW (champlain_view_new ()));
@@ -286,6 +283,18 @@ gdk_rgba_to_clutter_color (GdkRGBA *gdk_rgba_color,
   color->blue = CLAMP (gdk_rgba_color->blue * 255, 0, 255);
   color->alpha = CLAMP (gdk_rgba_color->alpha * 255, 0, 255);
 }
+
+static void
+get_background_color (GtkStyleContext *context,
+    GtkStateFlags state,
+    GdkRGBA *color)
+{
+  GdkRGBA *c;
+
+  gtk_style_context_get (context, state, "background-color", &c, NULL);
+  *color = *c;
+  gdk_rgba_free (c);
+}
 #endif
 
 
@@ -341,8 +350,8 @@ view_realize_cb (GtkWidget *widget,
     }
   champlain_marker_set_selection_text_color (&color);
 
-  gtk_style_context_get_background_color (style, gtk_style_context_get_state (style),
-                                          &gdk_rgba_color);
+  get_background_color (style, gtk_style_context_get_state (style),
+                        &gdk_rgba_color);
   gdk_rgba_to_clutter_color (&gdk_rgba_color, &color);
   if (color.alpha == 0)
     color.alpha = 255;
