@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2010-2012 Jiri Techet <techet@gmail.com>
+ * Copyright (C) 2010-2013 Jiri Techet <techet@gmail.com>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -55,10 +55,13 @@
 
 #include <math.h>
 
-G_DEFINE_ABSTRACT_TYPE (ChamplainMapSource, champlain_map_source, G_TYPE_INITIALLY_UNOWNED);
+struct _ChamplainMapSourcePrivate
+{
+  ChamplainMapSource *next_source;
+  ChamplainRenderer *renderer;
+};
 
-#define GET_PRIVATE(obj) \
-  (G_TYPE_INSTANCE_GET_PRIVATE ((obj), CHAMPLAIN_TYPE_MAP_SOURCE, ChamplainMapSourcePrivate))
+G_DEFINE_ABSTRACT_TYPE_WITH_PRIVATE (ChamplainMapSource, champlain_map_source, G_TYPE_INITIALLY_UNOWNED)
 
 enum
 {
@@ -67,12 +70,6 @@ enum
   PROP_RENDERER,
 };
 
-struct _ChamplainMapSourcePrivate
-{
-  ChamplainMapSource *next_source;
-  ChamplainRenderer *renderer;
-};
-
 static void
 champlain_map_source_get_property (GObject *object,
     guint prop_id,
@@ -167,8 +164,6 @@ champlain_map_source_class_init (ChamplainMapSourceClass *klass)
   GObjectClass *object_class = G_OBJECT_CLASS (klass);
   GParamSpec *pspec;
 
-  g_type_class_add_private (klass, sizeof (ChamplainMapSourcePrivate));
-
   object_class->finalize = champlain_map_source_finalize;
   object_class->dispose = champlain_map_source_dispose;
   object_class->get_property = champlain_map_source_get_property;
@@ -219,7 +214,7 @@ champlain_map_source_class_init (ChamplainMapSourceClass *klass)
 static void
 champlain_map_source_init (ChamplainMapSource *map_source)
 {
-  ChamplainMapSourcePrivate *priv = GET_PRIVATE (map_source);
+  ChamplainMapSourcePrivate *priv = champlain_map_source_get_instance_private (map_source);
 
   map_source->priv = priv;
 
