@@ -43,36 +43,6 @@
 
 static void exportable_interface_init (ChamplainExportableIface *iface);
 
-G_DEFINE_TYPE_WITH_CODE (ChamplainPathLayer, champlain_path_layer, CHAMPLAIN_TYPE_LAYER,
-    G_IMPLEMENT_INTERFACE (CHAMPLAIN_TYPE_EXPORTABLE, exportable_interface_init));
-
-#define GET_PRIVATE(obj) \
-  (G_TYPE_INSTANCE_GET_PRIVATE ((obj), CHAMPLAIN_TYPE_PATH_LAYER, ChamplainPathLayerPrivate))
-
-enum
-{
-  /* normal signals */
-  LAST_SIGNAL
-};
-
-enum
-{
-  PROP_0,
-  PROP_CLOSED_PATH,
-  PROP_STROKE_WIDTH,
-  PROP_STROKE_COLOR,
-  PROP_FILL,
-  PROP_FILL_COLOR,
-  PROP_STROKE,
-  PROP_VISIBLE,
-  PROP_SURFACE,
-};
-
-static ClutterColor DEFAULT_FILL_COLOR = { 0xcc, 0x00, 0x00, 0xaa };
-static ClutterColor DEFAULT_STROKE_COLOR = { 0xa4, 0x00, 0x00, 0xff };
-
-/* static guint signals[LAST_SIGNAL] = { 0, }; */
-
 struct _ChamplainPathLayerPrivate
 {
   ChamplainView *view;
@@ -120,6 +90,33 @@ struct _ChamplainPathLayerPrivate
   gboolean redraw_scheduled;
 };
 
+G_DEFINE_TYPE_WITH_CODE (ChamplainPathLayer, champlain_path_layer, CHAMPLAIN_TYPE_LAYER,
+    G_ADD_PRIVATE (ChamplainPathLayer)
+    G_IMPLEMENT_INTERFACE (CHAMPLAIN_TYPE_EXPORTABLE, exportable_interface_init))
+
+enum
+{
+  /* normal signals */
+  LAST_SIGNAL
+};
+
+enum
+{
+  PROP_0,
+  PROP_CLOSED_PATH,
+  PROP_STROKE_WIDTH,
+  PROP_STROKE_COLOR,
+  PROP_FILL,
+  PROP_FILL_COLOR,
+  PROP_STROKE,
+  PROP_VISIBLE,
+  PROP_SURFACE,
+};
+
+static ClutterColor DEFAULT_FILL_COLOR = { 0xcc, 0x00, 0x00, 0xaa };
+static ClutterColor DEFAULT_STROKE_COLOR = { 0xa4, 0x00, 0x00, 0xff };
+
+/* static guint signals[LAST_SIGNAL] = { 0, }; */
 
 static void set_surface (ChamplainExportable *exportable,
     cairo_surface_t *surface);
@@ -287,8 +284,6 @@ champlain_path_layer_class_init (ChamplainPathLayerClass *klass)
   GObjectClass *object_class = G_OBJECT_CLASS (klass);
   ChamplainLayerClass *layer_class = CHAMPLAIN_LAYER_CLASS (klass);
 
-  g_type_class_add_private (klass, sizeof (ChamplainPathLayerPrivate));
-
   object_class->finalize = champlain_path_layer_finalize;
   object_class->dispose = champlain_path_layer_dispose;
   object_class->get_property = champlain_path_layer_get_property;
@@ -425,10 +420,9 @@ initialize_child_actor (ChamplainPathLayer *self,
 static void
 champlain_path_layer_init (ChamplainPathLayer *self)
 {
-  ChamplainPathLayerPrivate *priv;
+  ChamplainPathLayerPrivate *priv = champlain_path_layer_get_instance_private (self);
 
-  self->priv = GET_PRIVATE (self);
-  priv = self->priv;
+  self->priv = priv;
   priv->view = NULL;
 
   priv->visible = TRUE;
@@ -858,7 +852,7 @@ update_surface (ChamplainPathLayer *layer,
       cairo_surface_destroy (new_surface);
     }
   /* When only the right actor is visible, no merging is required */
-  else if (!CLUTTER_ACTOR_IS_VISIBLE (priv->left_actor))
+  else if (!clutter_actor_is_visible (priv->left_actor))
     set_surface (CHAMPLAIN_EXPORTABLE (layer), priv->right_surface);
 }
 
@@ -992,7 +986,7 @@ set_view (ChamplainLayer *layer,
 static ChamplainBoundingBox *
 get_bounding_box (ChamplainLayer *layer)
 {
-  ChamplainPathLayerPrivate *priv = GET_PRIVATE (layer);
+  ChamplainPathLayerPrivate *priv = CHAMPLAIN_PATH_LAYER (layer)->priv;
   GList *elem;
   ChamplainBoundingBox *bbox;
 
